<img alt="Statement Coverage" src=".github/badges/coverage.svg" />

# Motionblinds BLE

Python package used to interface with Motionblinds motors using Bluetooth Low Energy (BLE).

# Installation

```bash
pip install motionblindsble
```
